% Create and write output object masks.
%
% Input:
%    im           - image
%    p_dets       - results of top-down poselet detector only
%    scene        - results of globalization
%    params_scene - globalization parameters
%    dir_mask     - base directory for mask output
%    name         - base filename for output
function obj_mask_create(im, p_dets, scene, params_scene, dir_mask, name);
   % get image size
   [sx sy sz] = size(im);
   % create mask for top-down poselet-only detections above threshold
   o_ids = find(p_dets.bounds_predictions.score > 12);
   mask_pl = obj_mask_dets( ...
      p_dets.bounds_predictions.select(o_ids), ...
      p_dets.poselet_hits, ...
      params_scene.fg_masks, ...
      [sx sy] ...
   );
   % create masks for globalization results
   o_ids = find(scene.dets.obj_bounds.score > params_scene.det_score_th);
   [mask_top mask_top_fg] = obj_mask_dets_fg( ...
      scene.dets.obj_bounds.select(o_ids), ...
      scene.dets.poselet_hits, ...
      params_scene.fg_masks, ...
      [sx sy], ...
      scene.dets.obj_mask_inds(o_ids), ...
      scene.dets.obj_mask_vals(o_ids) ...
   );
   % threshold masks
   th_mask_pl     = (mask_pl     > 0.07);
   th_mask_top    = (mask_top    > 0.07);
   th_mask_top_fg = (mask_top_fg > 0.07);
   % write thresholded masks (for benchmarking)
   cmap = VOClabelcolormap(256);
   classid = 15; % person class
   imwrite(uint8(classid.*th_mask_pl),cmap,fullfile(dir_mask,'pl',[name '.png']));
   imwrite(uint8(classid.*th_mask_top),cmap,fullfile(dir_mask,'top',[name '.png']));
   imwrite(uint8(classid.*th_mask_top_fg),cmap,fullfile(dir_mask,'top_fg',[name '.png']));
   % create visualization
   v_mask_pl     = mask_pl./(max(mask_pl(:)) + eps);
   v_mask_top    = mask_top./(max(mask_top(:)) + eps);
   v_mask_top_fg = mask_top_fg./(max(mask_top_fg(:)) + eps);
   mask_vis = ...
      cat(1, ...
         cat(2, v_mask_pl,    v_mask_top,    v_mask_top_fg), ...
         cat(2, v_mask_pl.*th_mask_pl, v_mask_top.*th_mask_top, v_mask_top_fg.*th_mask_top_fg) ...
      );
   mask_vis = ind2rgb(round((mask_vis).*255)+1,jet(256));
   if (sz == 1), im = repmat(im,[1 1 3]); end
   mask_vis = cat(2,cat(1,im,zeros(size(im))), mask_vis);
   imwrite(mask_vis,fullfile(dir_mask,'vis',[name '.png']));
end
