% Compute top-down figure/mask for all object detections in the image by 
% weighting their member poselet activations.
%
% mask = obj_mask_dets(obj_bounds, poselet_hits, fg_masks, [sx sy])
%
% Input:
%    obj_bounds      - predicted object bounds and member poselets
%    poselet_hits    - poselets detected in the image
%    fg_masks        - learned poselet figure/ground masks
%    [sx sy]         - image size
%
% Output:
%    mask            - object mask created using top-down poselet detections
function mask = obj_mask_dets(obj_bounds, poselet_hits, fg_masks, im_size)
   % initialize mask
   mask = zeros(im_size);
   % combine masks for all objects
   for n = 1:(obj_bounds.size)
      % get poselets used in object
      poselets_obj = poselet_hits.select(obj_bounds.src_idx{n});
      % compute mask for object
      mask_obj = obj_mask_poselets(poselets_obj, fg_masks, im_size);
      % combine masks
      mask = max(mask, mask_obj);
   end
end
