% Compute figure/ground masks (top-down and combined) for a single detected 
% object from its member poselet activations and associated member pixels.
%
% [mask mask_fg] = ...
%    obj_mask_poselets_fg(poselet_hits, fg_masks, [sx sy], px_inds, px_vals)
%
% Input:
%    poselet_hits    - poselets belonging to detected object
%    fg_masks        - learned poselet figure/ground masks
%    [sx sy]         - image size
%    px_inds         - indices of pixels associated with object
%    px_vals         - weight with which pixel is associated to object
%
% Output:
%    mask            - object mask created using top-down poselet detections
%    mask_fg         - reweighted object mask using both poselets and pixels
function [mask mask_fg] = ...
   obj_mask_poselets_fg(poselet_hits, fg_masks, im_size, px_inds, px_vals)
   % compute top-down mask from poselets
   mask = obj_mask_poselets(poselet_hits, fg_masks, im_size);
   % construct pixel membership mask
   px_mask = zeros(im_size);
   px_mask(px_inds) = px_vals;
   % warp top-down mask onto pixel membership mask
   mask_fg = normalize_hist(mask, px_mask);
end
