% Extract detections and write them to a text file in VOC evaluation format.
%
% voc_det_extract(fname, name, obj_bounds, [sx sy], det_th)
%
% Input:
%    fname           - output filename
%    name            - name of image
%    obj_bounds      - bounds and scores of detected objects
%    [sx sy]         - image size
%    det_th          - detection score cutoff threshold
%                      (don't output detections at or below this threshold)
function voc_det_extract(fname, name, obj_bounds, im_size, det_th)
   % default threshold
   if (nargin < 5), det_th = 0; end
   % extract image size
   sx = im_size(1);
   sy = im_size(2);
   % open file
   f = fopen(fname,'w');
   % write each detection
   for n = 1:(obj_bounds.size)
      % get score
      score = double(obj_bounds.score(n));
      % get bounding box
      bounds = round(double(obj_bounds.bounds(n,:)));
      ymin = max(1,bounds(1)); ymax = min(sy,bounds(1)+bounds(3)-1);
      xmin = max(1,bounds(2)); xmax = min(sx,bounds(2)+bounds(4)-1);
      % check if score is above threshold
      if (score > det_th)
         % write detection
         fprintf(f,[name ' %f %f %f %f %f\n'],score,ymin,xmin,ymax,xmax);
      end
   end
   % close file
   fclose(f);
end
