% example image file
file_im = 'demo/2008_000215.jpg';

% output directory
dir_out = 'demo';

% recompute results even if they already exist?
recompute_pb       = false;
recompute_poselets = false;
recompute_scene    = false;

% default globalization parameters
params = seg_obj('params');

% segment classifier coefficients (for refining object masks)
refine = load('refinement_trained.mat');

% result files
[pathstr fname ext] = fileparts(file_im);
file_pb       = fullfile(dir_out,[fname '-pb.mat']);
file_poselets = fullfile(dir_out,[fname '-poselets.mat']);
file_scene    = fullfile(dir_out,[fname '-scene.mat']);

% load image
im_u8 = imread(file_im);
im    = double(im_u8)./255;

% compute or load pb
if ((recompute_pb) || (~exist(file_pb,'file')))
   pb = compute_pb(im);
   pb_save(pb, file_pb);
else
   pb = pb_load(file_pb);
end

% compute or load poselets
if ((recompute_poselets) || (~exist(file_poselets,'file')))
   p_dets = compute_poselets(im_u8);
   save(file_poselets,'p_dets');
else
   p_dets = load(file_poselets,'p_dets');
   p_dets = p_dets.p_dets;
end

% compute or load globalization result
if ((recompute_scene) || (~exist(file_scene,'file')))
   scene = seg_obj(pb, p_dets.poselet_hits, params);
   save(file_scene,'scene');
else
   scene = load(file_scene,'scene');
   scene = scene.scene;
end

% create visualization
vis = vis_generate(im, scene);

% refine detections by reclassifying segments
[sdata sfeat]  = seg_features(scene, im);
[f_mx has_det] = seg_feature_mx(sfeat);
pred    = 1./(1 + exp(-f_mx*refine.beta));
pred_th = (pred > refine.thresh).*(has_det);

% display detection and segmentation results
vis_view(vis);

% display hard classification of segents
figure; imagesc(pred_th(sdata.seg_arr{1}.seg));
title('Person Mask Refinement by Segment Classifier');
axis('image','off'); colorbar; caxis([0 1]);
