% Construct connections to impose figure/ground prior on poselet part nodes.
%
% [i j c theta] = affinity_fg_prior(poselet_hits, upsilon)
%
% Input:
%    poselet_hits - poselets detected in the image
%    upsilon      - affinity score scale parameter
%
% Output:
%    (i,j)        - indices into sparse matrix of part-fg node relationships
%    c            - confidence on pairwise relationships
%    theta        - relative pairwise ordering relationships
%
% The returned indices range over the part, surround, and global surround (fg) 
% nodes, starting at 1 for the first part node, with surround nodes following
% the last part node.
function [i j c theta] = affinity_fg_prior(poselet_hits, upsilon)
   % get number of poselets
   n_poselets = poselet_hits.size;
   % rotate part nodes with respect to global surround node
   i = (1:n_poselets).';
   j = ones([n_poselets 1]) + 2.*n_poselets;
   score_mx = double([poselet_hits.score(:)]);
   c = exp(-(1-[score_mx(:)])./upsilon);
   theta = ones([n_poselets 1]);
end
