% Sort eigenvectors by importance (smallest eigenvalue first).
% Also return weights (inverse square root of eigenvalues).
%
% [evecs evals weights] = evecs_sort(evecs, evals)
%
% Input:
%    evecs           - eigenvectors (ne x nv matrix)
%    evals           - eigenvalues  (length nv vector)
%
% Output:
%    evecs           - eigenvectors sorted in ascending order by eigenvalue
%    evals           - eigenvalues in ascending order
%    weights         - weight on each eigenvector 
%                      (used in defining distance metric in embedding space)
function [evecs evals weights] = evecs_sort(evecs, evals)
   % compute weights
   weights = zeros(size(evals));
   for v = 1:numel(evals)
      if (abs(evals(v)) > 0)
         weights(v) = 1./sqrt(abs(evals(v)));
      end
   end
   % sort by weight
   [junk inds] = sort(weights);
   evecs   = evecs(:,inds(end:-1:1));
   evals   = evals(inds(end:-1:1));
   weights = weights(inds(end:-1:1));
end
