% Load poselet model and convert poselet figure/ground masks to be aligned with
% poselet detections (take inner 1/4..3/4 of each mask and upscale by 2).
%
% poselets_model = load_poselets(filename)
%
% Input:
%    filename           - file containing poselet model
%
% Output:
%    poselets_model.    - poselet model
%       fg_masks           - figure/ground masks, aligned with detections
%       model              - model parameters
%       poselet_thumbs     - example thumbnail images for each poselet
function poselets_model = load_poselets(filename)
   % load model
   poselets_model = load(filename);
   % align figure/ground masks with poselet detection bounding boxes
   % (stored mask is twice as large at half resolution)
   n_masks = numel(poselets_model.fg_masks);
   for n = 1:n_masks
      fg_mask = poselets_model.fg_masks{n};
      [h w] = size(fg_mask);
      poselets_model.fg_masks{n} = imresize( ...
         fg_mask(round(h/4):round(h*3/4),round(w/4):round(w*3/4)),2,'bilinear');
   end
end
