% Display visualization of scene globalization results.
%
% vis_view(vis, [fh])
%
% Input:
%    vis       - visualization data (see: vis_generate)
%    fh        - figure handle (optional; create new figure if not specified)
function vis_view(vis, fh)
   % check arguments
   if ((nargin < 2) || isempty(fh)), fh = figure; end
   % get number of objects
   n_obj = numel(vis.obj_bbox);
   % show scene results
   ah_bbox = subplot(n_obj+1,4,1,'Parent',fh);
   ah_ucm  = subplot(n_obj+1,4,2,'Parent',fh);
   ah_fg   = subplot(n_obj+1,4,3,'Parent',fh);
   ah_im   = subplot(n_obj+1,4,4,'Parent',fh);
   imagesc(vis.bbox,'Parent',ah_bbox);
   imagesc(repmat(vis.ucm,[1 1 3]), 'Parent',ah_ucm);
   imagesc(vis.fg,  'Parent',ah_fg);
   imagesc(vis.im,  'Parent',ah_im);
   axis(ah_bbox,'off'); axis(ah_bbox,'image');
   axis(ah_ucm,'off');  axis(ah_ucm,'image');
   axis(ah_fg,'off');   axis(ah_fg,'image');
   axis(ah_im,'off');   axis(ah_im,'image');
   title(ah_bbox,'Object Detections');
   title(ah_ucm,'UCM');
   title(ah_fg,'Figure/Ground');
   title(ah_im,'Image');
   % show object detection results
   for n = 1:n_obj
      ah_obj_bbox = subplot(n_obj+1,4,4*n+1,'Parent',fh);
      ah_obj_clus = subplot(n_obj+1,4,4*n+2,'Parent',fh);
      ah_obj_fg   = subplot(n_obj+1,4,4*n+3,'Parent',fh);
      ah_obj_im   = subplot(n_obj+1,4,4*n+4,'Parent',fh);
      imagesc(vis.obj_bbox{n},'Parent',ah_obj_bbox);
      imagesc(vis.obj_clus{n},'Parent',ah_obj_clus);
      imagesc(vis.obj_fg{n},  'Parent',ah_obj_fg);
      imagesc(vis.obj_im{n},  'Parent',ah_obj_im);
      axis(ah_obj_bbox,'off'); axis(ah_obj_bbox,'image');
      axis(ah_obj_clus,'off'); axis(ah_obj_clus,'image');
      axis(ah_obj_fg,'off');   axis(ah_obj_fg,'image');
      axis(ah_obj_im,'off');   axis(ah_obj_im,'image');
      title(ah_obj_bbox,['Score = ' num2str(vis.obj_scores(n),'%3.2f')]);
      if (n == 1)
         title(ah_obj_clus,'Keypoints');
         title(ah_obj_fg,'Object Mask');
         title(ah_obj_im,'Object');
      end
   end
end
