% Write scene visualization to image files.
%
% vis_write(vis, dirname)
%
% Input:
%    vis       - visualization data (see: vis_generate)
%    dirname   - directory name in which to create output
function vis_write(vis, dirname)
   % create directory if it does not exist
   if (~exist(dirname,'dir')), mkdir(dirname); end
   % convert figure/ground to heat map
   fg     = ind2rgb(round((vis.fg).*255)+1,jet(256));
   det_fg = ind2rgb(round((vis.det_fg).*255)+1,jet(256));
   % create image outputs
   imwrite(vis.im,         fullfile(dirname,'im.png'));
   imwrite(fg,             fullfile(dirname,'fg.png'));
   imwrite(vis.fg_im,      fullfile(dirname,'fg_im.png'));
   imwrite(vis.ucm,        fullfile(dirname,'ucm.png'));
   imwrite(det_fg,         fullfile(dirname,'det_fg.png'));
   imwrite(vis.bbox,       fullfile(dirname,'bbox.png'));
   imwrite(vis.bbox_color, fullfile(dirname,'bbox_color.png'));
   % initialize summary image output
   n_obj = numel(vis.obj_bbox);
   im_arr = cell([(n_obj+1) 1]);
   im_arr{1} = cat(2, vis.bbox, repmat(vis.ucm,[1 1 3]), fg, vis.im);
   % create per object outputs
   for n = 1:n_obj
      % grab object data
      o_bbox = vis.obj_bbox{n};
      o_clus = vis.obj_clus{n};
      o_fg   = vis.obj_fg{n};
      o_im   = vis.obj_im{n};
      % convert figure/ground to heat map
      o_fg = ind2rgb(round(o_fg.*255)+1,jet(256));
      % write output
      imwrite( ...
         o_bbox, ...
         fullfile(dirname,['obj_bbox_' num2str(n) '.png']) ...
      );
      imwrite( ...
         o_clus, ...
         fullfile(dirname,['obj_clus_' num2str(n) '.png']) ...
      );
      imwrite( ...
         o_fg, ...
         fullfile(dirname,['obj_fg_' num2str(n) '.png']) ...
      );
      imwrite( ...
         o_im, ...
         fullfile(dirname,['obj_im_' num2str(n) '.png']) ...
      );
      % store in summary image
      im_arr{n+1} = cat(2, o_bbox, o_clus, o_fg, o_im);
   end
   % write summary visualization
   im_all = cell2mat(im_arr);
   imwrite(im_all, fullfile(dirname,'all.png'));
end
