% Run segment classifier.
function ref_classify(beta, thresh, dir_im, dir_scene, dir_out, show_disp)
   if (nargin < 3)
      dir_im = '/home/mmaire/vocdata/JPEGImages/';
   end
   if (nargin < 4)
      dir_scene = '/home/mmaire/vocdata/scene/';
   end
   if (nargin < 5)
      dir_out = '/home/mmaire/vocdata/out/';
   end
   if (nargin < 6)
      show_disp = false;
   end

   names = dir([dir_scene '*.mat']); names = {names.name};
   for n = 1:numel(names), name = names{n}; names{n} = name(1:end-10); end

   n_imgs = numel(names);

   for n = 1:n_imgs
      disp(['results for image ' num2str(n) ' of ' num2str(n_imgs)]);
      % load data
      name = names{n};
      im    = double(imread([dir_im name '.jpg']))./255;
      scene = load([dir_scene name '-scene.mat']);
      scene = scene.scene;
      % compute features
      [sdata sfeat]  = seg_features(scene, im);
      [f_mx has_det] = seg_feature_mx(sfeat);
      % predict foreground probability
      pred    = 1./(1 + exp(-f_mx*beta));
      pred_th = (pred > thresh).*(has_det);
      if (show_disp)
         % display prediction
         figure(1); imagesc(im); title('image'); axis('image');
         figure(2); imagesc(scene.fg.fg_pixels); title('figure/ground'); axis('image'); colorbar;
         figure(3); imagesc(pred(sdata.seg_arr{1}.seg)); title('predicted figure/ground'); axis('image'); colorbar; caxis([0 1]);
         figure(4); imagesc(pred_th(sdata.seg_arr{1}.seg)); title('predicted figure/ground'); axis('image'); colorbar; caxis([0 1]);
         pause;
      else
         % create output mask for benchmarking
         cmap = VOClabelcolormap(256);
         classid = 15; % person class
         imwrite( ...
            uint8(classid.*pred_th(sdata.seg_arr{1}.seg)), ...
            cmap, ...
            fullfile(dir_out,[name '.png']) ...
         );
      end
   end
end
