% Train segment classifier.
function [beta thresh] = ref_train(dir_im, dir_gt, dir_scene)
   if (nargin < 1)
      dir_im = '/home/mmaire/vocdata/JPEGImages/';
   end
   if (nargin < 2)
      dir_gt = '/home/mmaire/vocdata/SegmentationClass/';
   end
   if (nargin < 3)
      dir_scene = '/home/mmaire/vocdata/scene/';
   end

   names = dir([dir_scene '*.mat']); names = {names.name};
   for n = 1:numel(names), name = names{n}; names{n} = name(1:end-10); end

   % allocate feature arrays
   n_imgs = numel(names);
   f_mx_arr     = cell([n_imgs 1]);
   has_det_arr  = cell([n_imgs 1]);
   gt_label_arr = cell([n_imgs 1]);
   weights_arr  = cell([n_imgs 1]);

   % compute features for each image
   for n = 1:n_imgs
      disp(['compute features for image ' num2str(n) ' of ' num2str(n_imgs)]);
      % load data
      name = names{n};
      im    = double(imread([dir_im name '.jpg']))./255;
      im_gt = double(imread([dir_gt name '.png']));
      scene = load([dir_scene name '-scene.mat']);
      scene = scene.scene;
      % compute features
      [sdata sfeat]       = seg_features(scene, im, im_gt);
      [f_mx has_det]      = seg_feature_mx(sfeat);
      [gt_labels weights] = seg_feature_gt(sfeat);
      % store features
      gt_label_arr{n} = gt_labels;
      has_det_arr{n}  = has_det;
      f_mx_arr{n}     = f_mx;
      weights_arr{n}  = weights;
   end

   % concatenate training examples
   f_mx_all      = cell2mat(f_mx_arr((floor(n_imgs./2)+1):n_imgs));
   has_det_all   = cell2mat(has_det_arr((floor(n_imgs./2)+1):n_imgs));
   gt_labels_all = cell2mat(gt_label_arr((floor(n_imgs./2)+1):n_imgs));
   weights_all   = cell2mat(weights_arr((floor(n_imgs./2)+1):n_imgs));

   % select examples for which there is an associated detection
   train_inds = find(has_det_all);

   gt_labels_tr = gt_labels_all(train_inds);
   f_mx_tr      = f_mx_all(train_inds,:);
   weights_tr   = weights_all(train_inds);

   % train classifier
   [beta,p,lli]  = logist2(gt_labels_tr, f_mx_tr, weights_tr);

   thresh = 0.35;
end
