% Extract segment feature matrix.
%
% [f_mx has_det] = seg_feature_mx(sfeat)
%
% Input:
%    sfeat        - features for each segment
%
% Output:
%    f_mx         - feature matrix (# regions) x (# features)
%    has_det      - indicator of whether each region has an associated object
function [f_mx has_det] = seg_feature_mx(sfeat)
   n_reg = numel(sfeat.obj_id);
   f_mx = cat(2, ...
      sfeat.f.frac_size, ...
      sfeat.f.fg_norm_avg, ...
      sfeat.f.fg_diff_avg, ...
      sfeat.f.fg_diff_max, ...
      sfeat.f.pl_avg, ...
      sfeat.f.pl_diff_avg, ...
      sfeat.f.pl_diff_max, ...
      sfeat.f.cov_fg, ...
      sfeat.f.cov_pl, ...
      sfeat.f.aff_obj_center, ...
      sfeat.f.aff_obj_x, ...
      sfeat.f.aff_obj_y, ...
      ones([n_reg 1]) ...
   );
   has_det = (sfeat.obj_id > 0);
end
