% View projection of region features used in refinement onto base segmentation.
%
% view_seg_features(sdata, sfeat, fh)
%
% Input:
%    sdata           - segment data structure (created by seg_features)
%    sfeat           - features for each segment (created by seg_features)
%    fh              - starting figure handle to use
function view_seg_features(sdata, sfeat, fh)
   % get base level segmentation
   seg = sdata.seg_arr{1}.seg;
   % get number of ucm levels at which features were computed
   n_ucm_th = size(sfeat.f.seg_size,2);
   % display features at each level
   for lvl = 1:n_ucm_th
      % extract features at level
      frac_size      = sfeat.f.frac_size(:,lvl);
      fg_norm_avg    = sfeat.f.fg_norm_avg(:,lvl);
      fg_diff_avg    = sfeat.f.fg_diff_avg(:,lvl);
      fg_diff_max    = sfeat.f.fg_diff_max(:,lvl);
      pl_avg         = sfeat.f.pl_avg(:,lvl);
      pl_diff_avg    = sfeat.f.pl_diff_avg(:,lvl);
      pl_diff_max    = sfeat.f.pl_diff_max(:,lvl);
      cov_fg         = sfeat.f.cov_fg(:,lvl);
      cov_pl         = sfeat.f.cov_pl(:,lvl);
      aff_obj_center = sfeat.f.aff_obj_center(:,lvl);
      aff_obj_ur     = sfeat.f.aff_obj_ur(:,lvl);
      aff_obj_ul     = sfeat.f.aff_obj_ul(:,lvl);
      aff_obj_lr     = sfeat.f.aff_obj_lr(:,lvl);
      aff_obj_ll     = sfeat.f.aff_obj_ll(:,lvl);
      % display level
      disp(['Displaying segment features at level ' num2str(lvl)]);
      % display cues - region size
      figure(fh);
      imagesc(frac_size(seg)); title(['fractional size - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      % display cues - figure/ground from embedding
      figure(fh+1);
      subplot(1,3,1);
      imagesc(fg_norm_avg(seg)); title(['fg norm avg - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,3,2);
      imagesc(fg_diff_avg(seg)); title(['fg diff avg - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,3,3);
      imagesc(fg_diff_max(seg)); title(['fg diff max - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      % display cues - figure/ground from poselets
      figure(fh+2);
      subplot(1,3,1);
      imagesc(pl_avg(seg)); title(['pl avg - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,3,2);
      imagesc(pl_diff_avg(seg)); title(['pl diff avg - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,3,3);
      imagesc(pl_diff_max(seg)); title(['pl diff max - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      % display cues - coverage
      figure(fh+4);
      subplot(1,2,1);
      imagesc(cov_fg(seg)); title(['coverage - fg - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,2,2);
      imagesc(cov_pl(seg)); title(['coverage - pl - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      % display cues - positition relative to bounding box
      figure(fh+5);
      subplot(1,5,1);
      imagesc(aff_obj_center(seg)); title(['aff center - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,5,2);
      imagesc(aff_obj_ur(seg)); title(['aff ur - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,5,3);
      imagesc(aff_obj_ul(seg)); title(['aff ul - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,5,4);
      imagesc(aff_obj_lr(seg)); title(['aff lr - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      subplot(1,5,5);
      imagesc(aff_obj_ll(seg)); title(['aff ll - ' num2str(lvl)]);
      axis('image','off'); colorbar;
      if (lvl < n_ucm_th)
         pause;
      end
   end
end
