% Compute and return poselet detection results.
%
% p_dets = compute_poselets(im, params)
%
% Input:
%    im                 - image (uint8 format)
%    params.            - poselet parameters (defaults used if not specified)
%       model              - poselet model
%       fg_masks           - poselet figure/ground masks
%       poselet_thumbs     - poselet thumbnails
%
% Output:
%    p_dets.            - detections using poselets
%       poselet_hits       - poselets detected in image
%       bounds_predictions - object bounding box predictions
%       torso_predictions  - object torso predictions
function p_dets = poselet_compute(im, params)
   % default parameters
   if (nargin < 2), params = load('poselets_model_sep10.mat'); end
   % extract parameter fields
   model          = params.model;
   fg_masks       = params.fg_masks;
   poselet_thumbs = params.poselet_thumbs;
   % configure
   detection_config;
   faster_detection = false; % set to false to run slower but higher quality
   enable_bigq = true;       % enables context poselets
   if faster_detection
       disp('Warning: Using parameters optimized for speed over accuracy');
       config.DETECTION_IMG_MIN_NUM_PIX = 500^2;  % if the number of pixels in a detection image is < DETECTION_IMG_SIDE^2, scales up the image to meet that threshold
       config.DETECTION_IMG_MAX_NUM_PIX = 750^2;
       config.PYRAMID_SCALE_RATIO = 2;
   end
   if ~enable_bigq
      model = rmfield(model,'bigq_weights');
      model = rmfield(model,'bigq_logit_coef');
   end
   % detect
   [bounds_predictions poselet_hits torso_predictions] = ...
      detect_objects_in_image(im,model);
   % store detections
   p_dets.poselet_hits       = poselet_hits;
   p_dets.bounds_predictions = bounds_predictions;
   p_dets.torso_predictions  = torso_predictions;
end
